Enum rocket_contrib::Value
[−]
pub enum Value {
Null,
Bool(bool),
Number(Number),
String(String),
Array(Vec<Value>),
Object(Map<String, Value>),
}Represents any valid JSON value.
Variants
NullRepresents a JSON null value.
Bool(bool)Represents a JSON boolean.
Number(Number)Represents a JSON number, whether integer or floating point.
String(String)Represents a JSON string.
Array(Vec<Value>)Represents a JSON array.
Object(Map<String, Value>)Represents a JSON object.
Methods
impl Value
fn get<I>(&self, index: I) -> Option<&Value> where I: Index
Index into a JSON array or map. A string index can be used to access a value in a map, and a usize index can be used to access an element of an array.
Returns None if the type of self does not match the type of the
index, for example if the index is a string and self is an array or a
number. Also returns None if the given key does not exist in the map
or the given index is not within the bounds of the array.
let object = json!({ "A": 65, "B": 66, "C": 67 }); assert_eq!(*object.get("A").unwrap(), json!(65)); let array = json!([ "A", "B", "C" ]); assert_eq!(*array.get(2).unwrap(), json!("C")); assert_eq!(array.get("A"), None);
Square brackets can also be used to index into a value in a more concise
way. This returns Value::Null in cases where get would have returned
None.
let object = json!({ "A": ["a", "á", "à"], "B": ["b", "b́"], "C": ["c", "ć", "ć̣", "ḉ"], }); assert_eq!(object["B"][0], json!("b")); assert_eq!(object["D"], json!(null)); assert_eq!(object[0]["x"]["y"]["z"], json!(null));
fn get_mut<I>(&mut self, index: I) -> Option<&mut Value> where I: Index
Mutably index into a JSON array or map. A string index can be used to access a value in a map, and a usize index can be used to access an element of an array.
Returns None if the type of self does not match the type of the
index, for example if the index is a string and self is an array or a
number. Also returns None if the given key does not exist in the map
or the given index is not within the bounds of the array.
let mut object = json!({ "A": 65, "B": 66, "C": 67 }); *object.get_mut("A").unwrap() = json!(69); let mut array = json!([ "A", "B", "C" ]); *array.get_mut(2).unwrap() = json!("D");
fn is_object(&self) -> bool
Returns true if the Value is an Object. Returns false otherwise.
fn as_object(&self) -> Option<&Map<String, Value>>
If the Value is an Object, returns the associated Map.
Returns None otherwise.
fn as_object_mut(&mut self) -> Option<&mut Map<String, Value>>
If the Value is an Object, returns the associated mutable Map.
Returns None otherwise.
fn is_array(&self) -> bool
Returns true if the Value is an Array. Returns false otherwise.
fn as_array(&self) -> Option<&Vec<Value>>
If the Value is an Array, returns the associated vector.
Returns None otherwise.
fn as_array_mut(&mut self) -> Option<&mut Vec<Value>>
If the Value is an Array, returns the associated mutable vector.
Returns None otherwise.
fn is_string(&self) -> bool
Returns true if the Value is a String. Returns false otherwise.
fn as_str(&self) -> Option<&str>
If the Value is a String, returns the associated str.
Returns None otherwise.
fn is_number(&self) -> bool
Returns true if the Value is a Number. Returns false otherwise.
fn is_i64(&self) -> bool
Returns true if the Value is a number that can be represented by i64.
fn is_u64(&self) -> bool
Returns true if the Value is a number that can be represented by u64.
fn is_f64(&self) -> bool
Returns true if the Value is a number that can be represented by f64.
fn as_i64(&self) -> Option<i64>
If the Value is a number, represent it as i64 if possible.
Returns None otherwise.
fn as_u64(&self) -> Option<u64>
If the Value is a number, represent it as u64 if possible.
Returns None otherwise.
fn as_f64(&self) -> Option<f64>
If the Value is a number, represent it as f64 if possible.
Returns None otherwise.
fn is_boolean(&self) -> bool
Returns true if the Value is a Boolean. Returns false otherwise.
fn as_bool(&self) -> Option<bool>
If the Value is a Boolean, returns the associated bool.
Returns None otherwise.
fn is_null(&self) -> bool
Returns true if the Value is a Null. Returns false otherwise.
fn as_null(&self) -> Option<()>
If the Value is a Null, returns ().
Returns None otherwise.
fn pointer(&'a self, pointer: &str) -> Option<&'a Value>
Looks up a value by a JSON Pointer.
JSON Pointer defines a string syntax for identifying a specific value within a JavaScript Object Notation (JSON) document.
A Pointer is a Unicode string with the reference tokens separated by /.
Inside tokens / is replaced by ~1 and ~ is replaced by ~0. The
addressed value is returned and if there is no such value None is
returned.
For more information read RFC6901.
Examples
let data = json!({ "x": { "y": ["z", "zz"] } }); assert_eq!(data.pointer("/x/y/1").unwrap(), &json!("zz")); assert_eq!(data.pointer("/a/b/c"), None);
fn pointer_mut(&'a mut self, pointer: &str) -> Option<&'a mut Value>
Looks up a value by a JSON Pointer and returns a mutable reference to that value.
JSON Pointer defines a string syntax for identifying a specific value within a JavaScript Object Notation (JSON) document.
A Pointer is a Unicode string with the reference tokens separated by /.
Inside tokens / is replaced by ~1 and ~ is replaced by ~0. The
addressed value is returned and if there is no such value None is
returned.
For more information read RFC6901.
Example of Use
extern crate serde_json; use serde_json::Value; use std::mem; fn main() { let s = r#"{"x": 1.0, "y": 2.0}"#; let mut value: Value = serde_json::from_str(s).unwrap(); // Check value using read-only pointer assert_eq!(value.pointer("/x"), Some(&1.0.into())); // Change value with direct assignment *value.pointer_mut("/x").unwrap() = 1.5.into(); // Check that new value was written assert_eq!(value.pointer("/x"), Some(&1.5.into())); // "Steal" ownership of a value. Can replace with any valid Value. let old_x = value.pointer_mut("/x").map(|x| mem::replace(x, Value::Null)).unwrap(); assert_eq!(old_x, 1.5); assert_eq!(value.pointer("/x").unwrap(), &Value::Null); }